==> vue-components-1.6.3.tgz: package/lib/pickList/src/PickList.vue.rd.js <==
import { defineComponent as oe, toRefs as ae, ref as V, watch as I, onMounted as re, openBlock as s, createElementBlock as a, createElementVNode as o, normalizeClass as y, createCommentVNode as d, createVNode as h, unref as e, toDisplayString as m, isRef as E, withCtx as _, Fragment as p, renderList as L, renderSlot as C, createBlock as F } from "vue";
import { useInfiniteScroll as ne } from "@regiondev/vue-hooks";
import { useVModels as ie, refDebounced as R } from "@vueuse/core";
import { useTransfer as W } from "./hooks/useTransfer.rd.js";
import { pickListProps as ce } from "./props.rd.js";
import "../../buttons/index.rd.js";
import N from "../../icons/states/EmptySearch.vue.rd.js";
import j from "../../icons/states/GenericEmpty.vue.rd.js";
import "../../input/index.rd.js";
import { RDotsSpinning as de } from "../../spinners/index.rd.js";
import { RAntCheckbox as w } from "../../form/index.rd.js";
import M from "../../input/Input.vue.rd.js";
import P from "../../buttons/src/Button.vue.rd.js";
const ue = { class: "flex flex-col md:!flex-row md:max-h-300px max-h-full space-x-2 r-pickList" }, he = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, me = { class: "border-theme border-b-solid border-1px border-b py-3 px-4 flex space-x-4" }, pe = { class: "mb-0 font-bold inline-flex items-center text-theme" }, fe = {
  key: 1,
  class: "px-2 py-3"
}, ve = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), be = {
  key: 2,
  class: "w-full flex justify-center absolute-center"
}, ge = ["onClick"], ye = { class: "flex items-center h-5" }, ke = {
  key: 0,
  class: "ml-3 text-sm"
}, xe = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, _e = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, Ce = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Available", -1), we = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Se = {
  key: 4,
  class: "mt-auto p-2 px-3"
}, Fe = { class: "justify-center flex flex-row sm:flex-col items-baseline sm:items-center sm:space-x-0 py-4 space-x-4 space-y-3" }, Ke = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-right" }, null, -1), Te = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-left" }, null, -1), $e = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, De = { class: "border-theme border-b-solid border-b-1px border-b py-3 px-4 flex space-x-4" }, Ae = { class: "mb-0 font-bold inline-flex items-center text-theme" }, Ve = {
  key: 1,
  class: "px-2 py-3"
}, Ie = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), Ee = { class: "scrollbox m-0 p-0 relative basis-100%" }, Le = ["onClick"], Re = { class: "flex items-center h-5" }, We = { class: "ml-3 text-sm flex items-center w-full" }, Ne = {
  key: 0,
  class: "ml-3 text-sm"
}, je = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, Me = ["onClick"], Pe = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, ze = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Selected", -1), Be = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Ue = {
  key: 2,
  class: "mt-auto p-2 px-3"
}, ot = /* @__PURE__ */ oe({
  __name: "PickList",
  props: ce(),
  emits: [
    "changeFilterTarget",
    "changeFilterSelected",
    "loadMore",
    "update:targetKeys"
  ],
  setup(z, { emit: S }) {
    const K = z, { targetKeys: f, selectedKeys: v } = ie(K), { idKey: n, disabledKeys: k, dataSource: x, loadingData: T } = ae(K), b = V(""), g = V(""), B = R(b, 500), U = R(g, 500);
    I(B, () => S("changeFilterTarget")), I(U, () => S("changeFilterSelected"));
    const [i, G, q, H] = W(k, f), [
      r,
      J,
      O,
      Q
    ] = W(k, v);
    re(() => {
      !f.value.length && x.value.length && (f.value = x.value.map((t) => t[n.value]));
    });
    function $(t, c) {
      t.target.checked ? r.value.push(c) : r.value = r.value.filter((u) => u !== c);
    }
    function D(t, c) {
      t.target.checked ? i.value.push(c) : i.value = i.value.filter((u) => u !== c);
    }
    function X(t) {
      t.target.checked ? i.value = Array.from(H.value) : i.value = [];
    }
    function Y(t) {
      t.target.checked ? r.value = Array.from(Q.value) : r.value = [];
    }
    function Z() {
      i.value.length && (v.value.push(...i.value), f.value = f.value.filter((t) => !i.value.includes(t)), i.value = []);
    }
    function A() {
      r.value.length && (f.value.push(...r.value), v.value = v.value.filter(
        (t) => !r.value.includes(t)
      ), r.value = []);
    }
    const { scrollElement: ee } = ne(() => S("loadMore"), { loading: T });
    function te(t) {
      r.value.push(t), A();
    }
    function le(t) {
      $({ target: { checked: !r.value.includes(t) } }, t);
    }
    function se(t) {
      D({ target: { checked: !i.value.includes(t) } }, t);
    }
    return (t, c) => (s(), a("div", ue, [
      o("div", {
        class: y([[t.cardClass], "dark:bg-rdSurface-800 bg-white round border-theme relative dark:shadow-lg max-h-300 md:max-h-full border border-solid card min-h-300px flex flex-col w-full sm:w-1/2 !p-0 overflow-hidden"])
      }, [
        t.isDisabled ? (s(), a("div", he)) : d("", !0),
        o("div", me, [
          h(e(w), {
            indeterminate: e(G),
            checked: e(q),
            onChange: X
          }, null, 8, ["indeterminate", "checked"]),
          o("span", pe, m(e(i).length) + "/" + m(e(f).length) + " " + m(t.availableText), 1)
        ]),
        t.showFilter ? (s(), a("div", fe, [
          h(e(M), {
            modelValue: e(b),
            "onUpdate:modelValue": c[0] || (c[0] = (l) => E(b) ? b.value = l : null),
            simple: "",
            class: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: _(() => [
              ve
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        e(T) ? (s(), a("div", be, [
          h(e(de))
        ])) : (s(), a("ul", {
          key: 3,
          ref_key: "scrollElement",
          ref: ee,
          class: "relative scrollbox basis-100% m-0 p-0"
        }, [
          (s(!0), a(p, null, L(e(x), (l) => (s(), a(p, {
            key: l[e(n)]
          }, [
            !e(v).includes(l[e(n)]) && l[t.textKey].toLowerCase().includes(e(b).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: "mb-1 items-center relative cursor-pointer px-4 py-2 flex hover:bg-primary-100 dark:hover:bg-primary-700 dark:hover:bg-opacity-20",
              onClick: (u) => se(l[e(n)])
            }, [
              o("div", ye, [
                h(e(w), {
                  checked: e(i).includes(l[e(n)]),
                  disabled: e(k).includes(l[e(n)]),
                  onChange: (u) => D(u, l[e(n)])
                }, null, 8, ["checked", "disabled", "onChange"])
              ]),
              t.$slots.renderItem ? C(t.$slots, "renderItem", {
                key: 1,
                item: l
              }) : (s(), a("div", ke, [
                o("label", xe, m(l[t.textKey]), 1)
              ]))
            ], 8, ge)) : d("", !0)
          ], 64))), 128)),
          o("div", _e, [
            e(b).length ? (s(), a(p, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              we
            ], 64)) : (s(), a(p, { key: 0 }, [
              h(e(N), { class: "w-80px h-auto pb-4" }),
              Ce
            ], 64))
          ])
        ], 512)),
        t.$slots.targetFooter ? (s(), a("div", Se, [
          C(t.$slots, "targetFooter")
        ])) : d("", !0)
      ], 2),
      o("div", Fe, [
        h(e(P), {
          disabled: t.isDisabled || e(i).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: y(["flex", { "!bg-opacity-20": t.isDisabled || e(i).length == 0 }]),
          onClick: Z
        }, {
          default: _(() => [
            Ke
          ]),
          _: 1
        }, 8, ["disabled", "class"]),
        t.oneWay ? d("", !0) : (s(), F(e(P), {
          key: 0,
          disabled: t.isDisabled || e(r).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: y(["flex", { "!bg-opacity-20": t.isDisabled || e(r).length == 0 }]),
          onClick: A
        }, {
          default: _(() => [
            Te
          ]),
          _: 1
        }, 8, ["disabled", "class"]))
      ]),
      o("div", {
        class: y([[t.cardClass], "dark:bg-rdSurface-800 bg-white round border-theme dark:shadow-lg max-h-300 md:max-h-full border border-solid relative min-h-300px overflow-hidden card flex flex-col w-full sm:w-1/2 !p-0"])
      }, [
        t.isDisabled ? (s(), a("div", $e)) : d("", !0),
        o("div", De, [
          t.oneWay ? d("", !0) : (s(), F(e(w), {
            key: 0,
            indeterminate: e(J),
            checked: e(O),
            onChange: Y
          }, null, 8, ["indeterminate", "checked"])),
          o("span", Ae, m(e(r).length) + "/" + m(e(v).length) + " " + m(t.selectedText), 1)
        ]),
        t.showFilter ? (s(), a("div", Ve, [
          h(e(M), {
            modelValue: e(g),
            "onUpdate:modelValue": c[1] || (c[1] = (l) => E(g) ? g.value = l : null),
            simple: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: _(() => [
              Ie
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        o("ul", Ee, [
          (s(!0), a(p, null, L(e(x), (l) => (s(), a(p, {
            key: l[e(n)]
          }, [
            e(v).includes(l[e(n)]) && l[t.textKey].toLowerCase().includes(e(g).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: y(["mb-1 relative px-4 py-2 flex items-center", {
                "hover:bg-primary-100 cursor-pointer dark:hover:bg-primary-700/20": !t.oneWay
              }]),
              onClick: (u) => !t.oneWay && le(l[e(n)])
            }, [
              o("div", Re, [
                t.oneWay ? d("", !0) : (s(), F(e(w), {
                  key: 0,
                  disabled: e(k).includes(l[e(n)]),
                  checked: e(r).includes(l[e(n)]),
                  onChange: (u) => $(u, l[e(n)])
                }, null, 8, ["disabled", "checked", "onChange"]))
              ]),
              o("div", We, [
                t.$slots.renderItem ? C(t.$slots, "renderItem", {
                  key: 1,
                  item: l
                }) : (s(), a("div", Ne, [
                  o("label", je, m(l[t.textKey]), 1)
                ])),
                t.oneWay ? (s(), a("span", {
                  key: 2,
                  class: "dark:text-red-400 dark:hover:text-red-300 ml-auto text-red-300 cursor-pointer hover:text-red-500 text-lg i-heroicons-outline:trash",
                  onClick: (u) => te(l[e(n)])
                }, null, 8, Me)) : d("", !0)
              ])
            ], 10, Le)) : d("", !0)
          ], 64))), 128)),
          o("div", Pe, [
            e(g).length ? (s(), a(p, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              Be
            ], 64)) : (s(), a(p, { key: 0 }, [
              h(e(N), { class: "w-80px h-auto pb-4" }),
              ze
            ], 64))
          ])
        ]),
        t.$slots.selectedFooter ? (s(), a("div", Ue, [
          C(t.$slots, "selectedFooter")
        ])) : d("", !0)
      ], 2)
    ]));
  }
});
export {
  ot as default
};

==> vue-components-1.6.7.tgz: package/lib/pickList/src/PickList.vue.rd.js <==
import { defineComponent as oe, toRefs as ae, ref as V, watch as I, onMounted as re, openBlock as s, createElementBlock as a, createElementVNode as o, normalizeClass as y, createCommentVNode as d, createVNode as h, unref as e, toDisplayString as m, isRef as E, withCtx as _, Fragment as f, renderList as L, renderSlot as C, createBlock as F } from "vue";
import { useInfiniteScroll as ne } from "@regiondev/vue-hooks";
import { useVModels as ie, refDebounced as R } from "@vueuse/core";
import { useTransfer as W } from "./hooks/useTransfer.rd.js";
import { pickListProps as ce } from "./props.rd.js";
import "../../buttons/index.rd.js";
import N from "../../icons/states/EmptySearch.vue.rd.js";
import j from "../../icons/states/GenericEmpty.vue.rd.js";
import "../../input/index.rd.js";
import { RDotsSpinning as de } from "../../spinners/index.rd.js";
import { RAntCheckbox as w } from "../../form/index.rd.js";
import M from "../../input/Input.vue.rd.js";
import P from "../../buttons/src/Button.vue.rd.js";
const ue = { class: "flex flex-col md:!flex-row md:flex-row md:max-h-300px max-h-full space-x-2 r-pickList" }, he = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, me = { class: "border-theme border-b-solid border-1px border-b py-3 px-4 flex space-x-4" }, fe = { class: "mb-0 font-bold inline-flex items-center text-theme" }, pe = {
  key: 1,
  class: "px-2 py-3"
}, ve = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), be = {
  key: 2,
  class: "w-full flex justify-center absolute-center"
}, ge = ["onClick"], ye = { class: "flex items-center h-5" }, ke = {
  key: 0,
  class: "ml-3 text-sm"
}, xe = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, _e = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, Ce = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Available", -1), we = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Se = {
  key: 4,
  class: "mt-auto p-2 px-3"
}, Fe = { class: "justify-center flex flex-row sm:flex-col items-baseline sm:items-center sm:space-x-0 py-4 space-x-4 space-y-3" }, Ke = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-right" }, null, -1), Te = /* @__PURE__ */ o("span", { class: "text-xl transform rotate-90 sm:rotate-0 i-heroicons-outline:chevron-left" }, null, -1), $e = {
  key: 0,
  class: "absolute cursor-not-allowed w-full h-full bg-gray-200/50 dark:bg-slate-900/70 z-10 top-0 left-0 round"
}, De = { class: "border-theme border-b-solid border-b-1px border-b py-3 px-4 flex space-x-4" }, Ae = { class: "mb-0 font-bold inline-flex items-center text-theme" }, Ve = {
  key: 1,
  class: "px-2 py-3"
}, Ie = /* @__PURE__ */ o("span", { class: "i-heroicons-outline:search" }, null, -1), Ee = { class: "scrollbox m-0 p-0 relative basis-100%" }, Le = ["onClick"], Re = { class: "flex items-center h-5" }, We = { class: "ml-3 text-sm flex items-center w-full" }, Ne = {
  key: 0,
  class: "ml-3 text-sm"
}, je = { class: "font-bold text-gray-700 dark:text-white cursor-pointer" }, Me = ["onClick"], Pe = { class: "first:flex absolute-center !opacity-90 text-center justify-center hidden flex-col items-center py-3" }, ze = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "No Items Selected", -1), Be = /* @__PURE__ */ o("span", { class: "text-lg text-muted mt-1" }, "Empty Search", -1), Ue = {
  key: 2,
  class: "mt-auto p-2 px-3"
}, ot = /* @__PURE__ */ oe({
  __name: "PickList",
  props: ce(),
  emits: [
    "changeFilterTarget",
    "changeFilterSelected",
    "loadMore",
    "update:targetKeys"
  ],
  setup(z, { emit: S }) {
    const K = z, { targetKeys: p, selectedKeys: v } = ie(K), { idKey: n, disabledKeys: k, dataSource: x, loadingData: T } = ae(K), b = V(""), g = V(""), B = R(b, 500), U = R(g, 500);
    I(B, () => S("changeFilterTarget")), I(U, () => S("changeFilterSelected"));
    const [i, G, q, H] = W(k, p), [
      r,
      J,
      O,
      Q
    ] = W(k, v);
    re(() => {
      !p.value.length && x.value.length && (p.value = x.value.map((t) => t[n.value]));
    });
    function $(t, c) {
      t.target.checked ? r.value.push(c) : r.value = r.value.filter((u) => u !== c);
    }
    function D(t, c) {
      t.target.checked ? i.value.push(c) : i.value = i.value.filter((u) => u !== c);
    }
    function X(t) {
      t.target.checked ? i.value = Array.from(H.value) : i.value = [];
    }
    function Y(t) {
      t.target.checked ? r.value = Array.from(Q.value) : r.value = [];
    }
    function Z() {
      i.value.length && (v.value.push(...i.value), p.value = p.value.filter((t) => !i.value.includes(t)), i.value = []);
    }
    function A() {
      r.value.length && (p.value.push(...r.value), v.value = v.value.filter(
        (t) => !r.value.includes(t)
      ), r.value = []);
    }
    const { scrollElement: ee } = ne(() => S("loadMore"), { loading: T });
    function te(t) {
      r.value.push(t), A();
    }
    function le(t) {
      $({ target: { checked: !r.value.includes(t) } }, t);
    }
    function se(t) {
      D({ target: { checked: !i.value.includes(t) } }, t);
    }
    return (t, c) => (s(), a("div", ue, [
      o("div", {
        class: y([[t.cardClass], "dark:bg-rdSurface-800 bg-white round border-theme relative dark:shadow-lg max-h-300 md:max-h-full border border-solid card min-h-300px flex flex-col w-full sm:w-1/2 !p-0 overflow-hidden"])
      }, [
        t.isDisabled ? (s(), a("div", he)) : d("", !0),
        o("div", me, [
          h(e(w), {
            indeterminate: e(G),
            checked: e(q),
            onChange: X
          }, null, 8, ["indeterminate", "checked"]),
          o("span", fe, m(e(i).length) + "/" + m(e(p).length) + " " + m(t.availableText), 1)
        ]),
        t.showFilter ? (s(), a("div", pe, [
          h(e(M), {
            modelValue: e(b),
            "onUpdate:modelValue": c[0] || (c[0] = (l) => E(b) ? b.value = l : null),
            simple: "",
            class: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: _(() => [
              ve
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        e(T) ? (s(), a("div", be, [
          h(e(de))
        ])) : (s(), a("ul", {
          key: 3,
          ref_key: "scrollElement",
          ref: ee,
          class: "relative scrollbox basis-100% m-0 p-0"
        }, [
          (s(!0), a(f, null, L(e(x), (l) => (s(), a(f, {
            key: l[e(n)]
          }, [
            !e(v).includes(l[e(n)]) && l[t.textKey].toLowerCase().includes(e(b).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: "mb-1 items-center relative cursor-pointer px-4 py-2 flex hover:bg-primary-100 dark:hover:bg-primary-700 dark:hover:bg-opacity-20",
              onClick: (u) => se(l[e(n)])
            }, [
              o("div", ye, [
                h(e(w), {
                  checked: e(i).includes(l[e(n)]),
                  disabled: e(k).includes(l[e(n)]),
                  onChange: (u) => D(u, l[e(n)])
                }, null, 8, ["checked", "disabled", "onChange"])
              ]),
              t.$slots.renderItem ? C(t.$slots, "renderItem", {
                key: 1,
                item: l
              }) : (s(), a("div", ke, [
                o("label", xe, m(l[t.textKey]), 1)
              ]))
            ], 8, ge)) : d("", !0)
          ], 64))), 128)),
          o("div", _e, [
            e(b).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              we
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(N), { class: "w-80px h-auto pb-4" }),
              Ce
            ], 64))
          ])
        ], 512)),
        t.$slots.targetFooter ? (s(), a("div", Se, [
          C(t.$slots, "targetFooter")
        ])) : d("", !0)
      ], 2),
      o("div", Fe, [
        h(e(P), {
          disabled: t.isDisabled || e(i).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: y(["flex", { "!bg-opacity-20": t.isDisabled || e(i).length == 0 }]),
          onClick: Z
        }, {
          default: _(() => [
            Ke
          ]),
          _: 1
        }, 8, ["disabled", "class"]),
        t.oneWay ? d("", !0) : (s(), F(e(P), {
          key: 0,
          disabled: t.isDisabled || e(r).length == 0,
          circle: "",
          icon: "",
          color: "primary",
          class: y(["flex", { "!bg-opacity-20": t.isDisabled || e(r).length == 0 }]),
          onClick: A
        }, {
          default: _(() => [
            Te
          ]),
          _: 1
        }, 8, ["disabled", "class"]))
      ]),
      o("div", {
        class: y([[t.cardClass], "dark:bg-rdSurface-800 bg-white round border-theme dark:shadow-lg max-h-300 md:max-h-full border border-solid relative min-h-300px overflow-hidden card flex flex-col w-full sm:w-1/2 !p-0"])
      }, [
        t.isDisabled ? (s(), a("div", $e)) : d("", !0),
        o("div", De, [
          t.oneWay ? d("", !0) : (s(), F(e(w), {
            key: 0,
            indeterminate: e(J),
            checked: e(O),
            onChange: Y
          }, null, 8, ["indeterminate", "checked"])),
          o("span", Ae, m(e(r).length) + "/" + m(e(v).length) + " " + m(t.selectedText), 1)
        ]),
        t.showFilter ? (s(), a("div", Ve, [
          h(e(M), {
            modelValue: e(g),
            "onUpdate:modelValue": c[1] || (c[1] = (l) => E(g) ? g.value = l : null),
            simple: "",
            placeholder: "Filter items..."
          }, {
            iconPrefix: _(() => [
              Ie
            ]),
            _: 1
          }, 8, ["modelValue"])
        ])) : d("", !0),
        o("ul", Ee, [
          (s(!0), a(f, null, L(e(x), (l) => (s(), a(f, {
            key: l[e(n)]
          }, [
            e(v).includes(l[e(n)]) && l[t.textKey].toLowerCase().includes(e(g).toLowerCase()) ? (s(), a("li", {
              key: 0,
              class: y(["mb-1 relative px-4 py-2 flex items-center", {
                "hover:bg-primary-100 cursor-pointer dark:hover:bg-primary-700/20": !t.oneWay
              }]),
              onClick: (u) => !t.oneWay && le(l[e(n)])
            }, [
              o("div", Re, [
                t.oneWay ? d("", !0) : (s(), F(e(w), {
                  key: 0,
                  disabled: e(k).includes(l[e(n)]),
                  checked: e(r).includes(l[e(n)]),
                  onChange: (u) => $(u, l[e(n)])
                }, null, 8, ["disabled", "checked", "onChange"]))
              ]),
              o("div", We, [
                t.$slots.renderItem ? C(t.$slots, "renderItem", {
                  key: 1,
                  item: l
                }) : (s(), a("div", Ne, [
                  o("label", je, m(l[t.textKey]), 1)
                ])),
                t.oneWay ? (s(), a("span", {
                  key: 2,
                  class: "dark:text-red-400 dark:hover:text-red-300 ml-auto text-red-300 cursor-pointer hover:text-red-500 text-lg i-heroicons-outline:trash",
                  onClick: (u) => te(l[e(n)])
                }, null, 8, Me)) : d("", !0)
              ])
            ], 10, Le)) : d("", !0)
          ], 64))), 128)),
          o("div", Pe, [
            e(g).length ? (s(), a(f, { key: 1 }, [
              h(e(j), { class: "w-80px h-auto pb-4" }),
              Be
            ], 64)) : (s(), a(f, { key: 0 }, [
              h(e(N), { class: "w-80px h-auto pb-4" }),
              ze
            ], 64))
          ])
        ]),
        t.$slots.selectedFooter ? (s(), a("div", Ue, [
          C(t.$slots, "selectedFooter")
        ])) : d("", !0)
      ], 2)
    ]));
  }
});
export {
  ot as default
};
